<?php
session_start();

define('DATA_FILE', 'sites.json'); 

function loadSitesData() {
    if (file_exists(DATA_FILE)) {
        $jsonData = file_get_contents(DATA_FILE);
        return json_decode($jsonData, true);
    }
    return ['sites' => []];
}

function saveSitesData($data) {
    file_put_contents(DATA_FILE, json_encode($data, JSON_PRETTY_PRINT));
}

$data = loadSitesData();

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['site_name']) && isset($_POST['site_description'])) {
        $newSite = filter_var(trim($_POST['site_name']), FILTER_SANITIZE_URL);
        $description = htmlspecialchars(trim($_POST['site_description']), ENT_QUOTES, 'UTF-8');

        if (filter_var($newSite, FILTER_VALIDATE_URL)) {
            $data['sites'][] = ['url' => $newSite, 'description' => $description, 'rating' => 0, 'ratings_count' => 0];
            saveSitesData($data);
            header('Location: index.php');
            exit;
        }
    } elseif (isset($_POST['rate_site'])) {
        $siteIndex = intval($_POST['site_index']);
        $rating = intval($_POST['rating']);

        if (isset($data['sites'][$siteIndex])) {
            $data['sites'][$siteIndex]['rating'] += $rating;
            $data['sites'][$siteIndex]['ratings_count'] += 1;
            saveSitesData($data);
            header('Location: index.php');
            exit;
        }
    }
}

// Function to calculate average rating
function getAverageRating($siteData) {
    return $siteData['ratings_count'] > 0 ? $siteData['rating'] / $siteData['ratings_count'] : 0;
}

// Sort sites by average rating (highest first)
usort($data['sites'], function($a, $b) {
    return getAverageRating($b) <=> getAverageRating($a); // PHP 7+ spaceship operator
});

?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>TopSiteScript</title>
    <link rel="icon" href="favicon.ico" type="image/x-icon"/>
    <style>
        body {
            font-family: Arial, sans-serif;
            background-color: #f0f4f8;
            color: #333;
            margin: 0;
            padding: 20px;
        }
        header {
            text-align: center;
            background: #4CAF50;
            color: white;
            padding: 20px 0;
            border-radius: 5px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.1);
        }
        h2 {
            text-align: center;
            color: #4CAF50;
        }
        #sites {
            max-width: 800px;
            margin: 0 auto;
            padding: 20px;
            border: 1px solid #4CAF50;
            border-radius: 5px;
            background-color: white;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.1);
        }
        .entry {
            border: 1px solid #4CAF50;
            border-radius: 5px;
            padding: 15px;
            margin-bottom: 10px;
            background-color: #f9f9f9;
        }
        .entry a {
            text-decoration: none;
            color: #4CAF50;
            font-weight: bold;
        }
        .entry a:hover {
            color: #45a049;
        }
        button {
            background-color: #4CAF50;
            color: white;
            padding: 8px 15px;
            border: none;
            border-radius: 5px;
            cursor: pointer;
        }
        button:hover {
            background-color: #45a049;
        }
        footer {
            text-align: center;
            margin-top: 20px;
        }
        .add-site-button {
            display: block;
            margin: 20px auto;
            text-align: center;
        }
    </style>
</head>
<body>

<header>
    <div align="center"><a href="https://topsitescript.site">TopSiteScript</a></div>
</header>
<script>
function submitRating(siteIndex) {
    let ratingSelect = document.querySelector(`#rating-${siteIndex}`);
    let rating = ratingSelect.value;

    // Create the form dynamically
    let form = document.createElement('form');
    form.method = 'POST';
    form.innerHTML = `<input type="hidden" name="site_index" value="${siteIndex}">
                     <input type="hidden" name="rating" value="${rating}">
                     <input type="hidden" name="rate_site" value="1">`;
    document.body.appendChild(form);
    form.submit();
}
</script>

<h2>Topsites</h2>

<div id="sites">
    <?php
        if (!empty($data['sites'])) {
            foreach ($data['sites'] as $index => $siteData) {
                $averageRating = getAverageRating($siteData);
                echo "<div class='entry'>
                        <a href='{$siteData['url']}' target='_blank'>{$siteData['url']}</a>
                        <p>{$siteData['description']}</p>
                        <p>Average Rating: " . number_format($averageRating, 1) . " (" . $siteData['ratings_count'] . " ratings)</p>
                        <select id='rating-$index'>
                            <option value=''>Rate this site</option>
                            <option value='1'>1 Star</option>
                            <option value='2'>2 Stars</option>
                            <option value='3'>3 Stars</option>
                            <option value='4'>4 Stars</option>
                            <option value='5'>5 Stars</option>
                        </select>
                        <button onclick='submitRating($index)'>Submit Rating</button>
                      </div>";
            }
        } else {
            echo "<p>No sites have been submitted yet.</p>";
        }
    ?>
</div>
<!-- Add a button to direct to the site submission page -->
<div class="add-site-button">
    <a href="submit.php">
        <button>Add A Site</button>
    </a>
</div>

<footer>
     <a href="admin.php">Admin Panel</a> 
</footer>

</body>
</html>